==> 0.1.tar.gz: emacs-personal/README.md <==
<p align="center">
  <a href="http://www.gnu.org/licenses/gpl-3.0.txt">
    <img src="https://img.shields.io/badge/license-GPL_3-green.svg" alt="License GPL 3" />
  </a>
</p>

<h1 align="center">emacs-personal</h1>
Lightweight configuration of emacs with basic utilities plus personal configuration

![emacs-personal](https://archive.org/download/libreweb/emacs-personal.png?raw=true "emacs-personal")

### Installation

#### Main mirror

1. `git clone https://libregit.org/heckyel/emacs-personal.git ~/.emacs.d/`

2. `emacs --batch --eval='(load-file "~/.emacs.d/init.el")'`

#### Secundary mirror

1. `git clone https://notabug.org/heckyel/emacs-personal.git ~/.emacs.d/`

2. `emacs --batch --eval='(load-file "~/.emacs.d/init.el")'`

### Fonts

`pacman -S ttf-hack` (for default)

`pacman -S ttf-anonymous-pro`

> change the typography in the [init-gui.el](modules/init-gui.el#L54) file

### Markdown Mode
- Require installed markdown in distro GNU+Linux, example:

  `apt-get install markdown` or `pacman -S markdown`

### Flycheck Mode
- Require installed the languages checking, example:

  `pacman -S shellcheck`    # bash, sh

  `pacman -S eslint`        # ECMAScript

  `pacman -S python-pylint` # python

### Neotree

Neotree comes by default in combination with all-the-icons.
So pressing `[f8]` will display (you must give "yes") a one-time screen to install all-the-icons fonts.

### Mode Python
- Require installed virtualenv:

        pacman -S python-virtualenv

- Enable or disable pyvenv-mode: <kdb>M-x</kdb> pyvenv-mode

- To create virtualenv from emacs:

        pyvenv-create

- To activate virtualenv from emacs:

        pyvenv-activate

==> 1.0.0.tar.gz: emacs-personal/README.md <==
<p align="center">
  <a href="http://www.gnu.org/licenses/gpl-3.0.txt">
    <img src="https://img.shields.io/badge/license-GPL_3-green.svg" alt="License GPL 3" />
  </a>
</p>

<h1 align="center">emacs-personal</h1>
Lightweight configuration of emacs with basic utilities plus personal configuration

![emacs-personal](https://archive.org/download/libreweb/emacs-personal-1.0.png?raw=true "emacs-personal")

### Installation

First step:

    M-x package-refresh-contents

#### Main mirror

1. `git clone https://libregit.org/heckyel/emacs-personal.git ~/.emacs.d/`

2. `emacs --batch --eval='(load-file "~/.emacs.d/init.el")'`

#### Secundary mirror

1. `git clone https://notabug.org/heckyel/emacs-personal.git ~/.emacs.d/`

2. `emacs --batch --eval='(load-file "~/.emacs.d/init.el")'`

### Fonts

`pacman -S ttf-hack` (for default)

`pacman -S ttf-anonymous-pro`

> change the typography in the [init-gui.el](modules/init-gui.el#L54) file

### Markdown Mode
- Require installed markdown in distro GNU+Linux, example:

  `apt-get install markdown` or `pacman -S markdown`

### Flycheck Mode
- Require installed the languages checking, example:

  `pacman -S shellcheck`    # bash, sh

  `pacman -S eslint`        # ECMAScript

  `pacman -S python-pylint` # python

### Neotree

Neotree comes by default in combination with all-the-icons.
So pressing `[f8]` will display (you must give "yes") a one-time screen to install all-the-icons fonts.

### Mode Python
- Require installed virtualenv:

        pacman -S python-virtualenv

- Enable or disable pyvenv-mode: <kdb>M-x</kdb> pyvenv-mode

- To create virtualenv from emacs:

        pyvenv-create

- To activate virtualenv from emacs:

        pyvenv-activate
